OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Fayl yükləndi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yüklənmiş fayl php.ini-də upload_max_filesize direktivini aşır",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklənilən faylın həcmi HTML formasinda olan MAX_FILE_SIZE direktivində təyin dilmiş həcmi aşır.",
    "The file was only partially uploaded" : "Fayl yalnız qismən yüklənib",
    "No file was uploaded" : "Heç bir fayl yüklənilmədi",
    "Missing a temporary folder" : "Müvəqqəti qovluq çatışmır",
    "Could not write file to disk" : "Faylı diskə yazmaq mümkün olmadı",
    "A PHP extension stopped the file upload" : "PHP uzantısı faylın yüklənməsini dayandırdı",
    "Translate" : "Translate",
    "guest" : "Qonaq",
    "Saved" : "Saxlanıldı",
    "Save changes" : "Dəyişiklikləri yaddaşa ver",
    "URL" : "URL",
    "to" : "doğru",
    "Replace" : "Əvəz edin",
    "Info" : "Info",
    "Warning" : "Xəbərdarlıq",
    "Edit" : "Dəyişiklik et"
},
"nplurals=2; plural=(n != 1);");
